View source: R/class-accuracy.R
| accuracy | R Documentation |
Accuracy is the proportion of the data that are predicted correctly.
accuracy(data, ...)
## S3 method for class 'data.frame'
accuracy(data, truth, estimate, na_rm = TRUE, case_weights = NULL, ...)
accuracy_vec(truth, estimate, na_rm = TRUE, case_weights = NULL, ...)
data |
Either a |
... |
Not currently used. |
truth |
The column identifier for the true class results
(that is a |
estimate |
The column identifier for the predicted class
results (that is also |
na_rm |
A |
case_weights |
The optional column identifier for case weights.
This should be an unquoted column name that evaluates to a numeric column
in |
Suppose a 2x2 table with notation:
| Reference | ||
| Predicted | Positive | Negative |
| Positive | A | B |
| Negative | C | D |
The formula used here is:
\text{Accuracy} = \frac{A + D}{A + B + C + D}
Accuracy is a metric that should be maximized. The output ranges from 0 to 1, with 1 indicating perfect predictions.
A tibble with columns .metric, .estimator,
and .estimate and 1 row of values.
For grouped data frames, the number of rows returned will be the same as the number of groups.
For accuracy_vec(), a single numeric value (or NA).
Accuracy extends naturally to multiclass scenarios. Because of this, macro and micro averaging are not implemented.
Max Kuhn
All class metrics
Other class metrics:
bal_accuracy(),
detection_prevalence(),
f_meas(),
fall_out(),
j_index(),
kap(),
markedness(),
mcc(),
miss_rate(),
npv(),
ppv(),
precision(),
recall(),
roc_dist(),
sedi(),
sens(),
spec()
library(dplyr)
data("two_class_example")
data("hpc_cv")
# Two class
accuracy(two_class_example, truth, predicted)
# Multiclass
# accuracy() has a natural multiclass extension
hpc_cv |>
filter(Resample == "Fold01") |>
accuracy(obs, pred)
# Groups are respected
hpc_cv |>
group_by(Resample) |>
accuracy(obs, pred)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.