| integrated-survival-metrics | R Documentation |
Integrated survival metrics summarize model performance across multiple evaluation time points into a single value by integrating dynamic survival metrics over time.
truth: a survival::Surv() object
...: list column of data frames containing .eval_time,
.pred_survival, and .weight_censored columns
brier_survival_integrated()Direction: minimize. Range: [0, 1]
dynamic-survival-metrics for time-dependent survival metrics
static-survival-metrics for static survival metrics
linear-pred-survival-metrics for linear predictor survival metrics
vignette("metric-types") for an overview of all metric types
library(dplyr)
data("lung_surv")
head(lung_surv)
lung_surv |>
brier_survival_integrated(truth = surv_obj, .pred)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.