| mse | R Documentation |
Calculate the mean squared error.
mse(data, ...)
## S3 method for class 'data.frame'
mse(data, truth, estimate, na_rm = TRUE, case_weights = NULL, ...)
mse_vec(truth, estimate, na_rm = TRUE, case_weights = NULL, ...)
data |
A |
... |
Not currently used. |
truth |
The column identifier for the true results
(that is |
estimate |
The column identifier for the predicted
results (that is also |
na_rm |
A |
case_weights |
The optional column identifier for case weights. This
should be an unquoted column name that evaluates to a numeric column in
|
MSE is a metric that should be minimized. The output ranges from 0 to Inf, with 0 indicating perfect predictions.
The formula for MSE is:
\text{MSE} = \frac{1}{n} \sum_{i=1}^{n} (\text{truth}_i - \text{estimate}_i)^2
A tibble with columns .metric, .estimator,
and .estimate and 1 row of values.
For grouped data frames, the number of rows returned will be the same as the number of groups.
For mse_vec(), a single numeric value (or NA).
rmse() for the root mean squared error, which is the square root
of MSE and is in the same units as the original data.
All numeric metrics
Other numeric metrics:
ccc(),
gini_coef(),
huber_loss(),
huber_loss_pseudo(),
iic(),
mae(),
mape(),
mase(),
mpe(),
msd(),
poisson_log_loss(),
rmse(),
rmse_relative(),
rpd(),
rpiq(),
rsq(),
rsq_trad(),
smape()
Other accuracy metrics:
ccc(),
huber_loss(),
huber_loss_pseudo(),
iic(),
mae(),
mape(),
mase(),
mpe(),
msd(),
poisson_log_loss(),
rmse(),
rmse_relative(),
smape()
# Supply truth and predictions as bare column names
mse(solubility_test, solubility, prediction)
library(dplyr)
set.seed(1234)
size <- 100
times <- 10
# create 10 resamples
solubility_resampled <- bind_rows(
replicate(
n = times,
expr = sample_n(solubility_test, size, replace = TRUE),
simplify = FALSE
),
.id = "resample"
)
# Compute the metric by group
metric_results <- solubility_resampled |>
group_by(resample) |>
mse(solubility, prediction)
metric_results
# Resampled mean estimate
metric_results |>
summarise(avg_estimate = mean(.estimate))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.