| quantile-metrics | R Documentation |
Quantile metrics evaluate predictions that consist of predicted quantiles rather than point predictions. These metrics assess the accuracy and calibration of distributional forecasts.
truth: numeric
estimate: hardhat::quantile_pred object
weighted_interval_score()Direction: minimize. Range: [0, Inf]
numeric-metrics for point prediction metrics
vignette("metric-types") for an overview of all metric types
library(hardhat)
df <- data.frame(
preds = quantile_pred(rbind(1:4, 8:11), c(0.2, 0.4, 0.6, 0.8)),
truth = c(3.3, 7.1)
)
df
weighted_interval_score(df, truth, preds)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.