View source: R/class-roc_dist.R
| roc_dist | R Documentation |
roc_dist() calculates the Euclidean distance from the observed
(sensitivity, specificity) point to the ideal corner (1, 1) in ROC space.
This is equivalent to the distance from (FPR, TPR) to (0, 1).
This metric is sometimes called "closest to top-left" in ROC analysis and
provides an alternative to j_index() for finding optimal classification
thresholds.
roc_dist(data, ...)
## S3 method for class 'data.frame'
roc_dist(
data,
truth,
estimate,
estimator = NULL,
na_rm = TRUE,
case_weights = NULL,
event_level = yardstick_event_level(),
...
)
roc_dist_vec(
truth,
estimate,
estimator = NULL,
na_rm = TRUE,
case_weights = NULL,
event_level = yardstick_event_level(),
...
)
data |
Either a |
... |
Not currently used. |
truth |
The column identifier for the true class results
(that is a |
estimate |
The column identifier for the predicted class
results (that is also |
estimator |
One of: |
na_rm |
A |
case_weights |
The optional column identifier for case weights.
This should be an unquoted column name that evaluates to a numeric column
in |
event_level |
A single string. Either |
Suppose a 2x2 table with notation:
| Reference | ||
| Predicted | Positive | Negative |
| Positive | A | B |
| Negative | C | D |
The formulas used here are:
\text{Sensitivity} = \frac{A}{A + C}
\text{Specificity} = \frac{D}{B + D}
\text{roc\_dist} = \sqrt{(1 - \text{Sensitivity})^2 +
(1 - \text{Specificity})^2}
roc_dist is a metric that should be minimized. The
output ranges from 0 to
1.4142135623731, with 0 indicating
perfect sensitivity and specificity.
A tibble with columns .metric, .estimator,
and .estimate and 1 row of values.
For grouped data frames, the number of rows returned will be the same as the number of groups.
For roc_dist_vec(), a single numeric value (or NA).
There is no common convention on which factor level should
automatically be considered the "event" or "positive" result
when computing binary classification metrics. In yardstick, the default
is to use the first level. To alter this, change the argument
event_level to "second" to consider the last level of the factor the
level of interest. For multiclass extensions involving one-vs-all
comparisons (such as macro averaging), this option is ignored and
the "one" level is always the relevant result.
Macro, micro, and macro-weighted averaging is available for this metric.
The default is to select macro averaging if a truth factor with more
than 2 levels is provided. Otherwise, a standard binary calculation is done.
See vignette("multiclass", "yardstick") for more information.
All class metrics
j_index() for Youden's J statistic, another metric for measuring closeness
to the ideal classification point.
Other class metrics:
accuracy(),
bal_accuracy(),
detection_prevalence(),
f_meas(),
fall_out(),
j_index(),
kap(),
markedness(),
mcc(),
miss_rate(),
npv(),
ppv(),
precision(),
recall(),
sedi(),
sens(),
spec()
# Two class
data("two_class_example")
roc_dist(two_class_example, truth, predicted)
# Multiclass
library(dplyr)
data(hpc_cv)
hpc_cv |>
filter(Resample == "Fold01") |>
roc_dist(obs, pred)
# Groups are respected
hpc_cv |>
group_by(Resample) |>
roc_dist(obs, pred)
# Weighted macro averaging
hpc_cv |>
group_by(Resample) |>
roc_dist(obs, pred, estimator = "macro_weighted")
# Vector version
roc_dist_vec(
two_class_example$truth,
two_class_example$predicted
)
# Making Class2 the "relevant" level
roc_dist_vec(
two_class_example$truth,
two_class_example$predicted,
event_level = "second"
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.