Tidy tools for quantifying how well model fits to a data set such as confusion matrices, class probability curve summaries, and regression metrics (e.g., RMSE).
Maintainer: Emil Hvitfeldt [email protected] (ORCID)
Authors:
Max Kuhn [email protected]
Davis Vaughan [email protected]
Other contributors:
RStudio [copyright holder, funder]
Useful links: