View source: R/class-fall_out.R
| fall_out | R Documentation |
These functions calculate the fall-out (false positive rate) of a
measurement system compared to a reference result (the "truth" or gold
standard). Fall-out is defined as 1 - specificity, or equivalently,
the proportion of negatives that are incorrectly classified as positives.
fall_out(data, ...)
## S3 method for class 'data.frame'
fall_out(
data,
truth,
estimate,
estimator = NULL,
na_rm = TRUE,
case_weights = NULL,
event_level = yardstick_event_level(),
...
)
fall_out_vec(
truth,
estimate,
estimator = NULL,
na_rm = TRUE,
case_weights = NULL,
event_level = yardstick_event_level(),
...
)
data |
Either a |
... |
Not currently used. |
truth |
The column identifier for the true class results
(that is a |
estimate |
The column identifier for the predicted class
results (that is also |
estimator |
One of: |
na_rm |
A |
case_weights |
The optional column identifier for case weights.
This should be an unquoted column name that evaluates to a numeric column
in |
event_level |
A single string. Either |
Fall-out is also known as the false positive rate (FPR) or the probability of false alarm.
When the denominator of the calculation is 0, fall-out is undefined.
This happens when both # true_negative = 0 and # false_positive = 0
are true, which means that there were no negatives. When computing binary
fall-out, a NA value will be returned with a warning. When computing
multiclass fall-out, the individual NA values will be removed, and the
computation will proceed, with a warning.
Suppose a 2x2 table with notation:
| Reference | ||
| Predicted | Positive | Negative |
| Positive | A | B |
| Negative | C | D |
The formula used here is:
\text{Fall-out} = \frac{B}{B + D}
Fall-out is a metric that should be minimized. The output ranges from 0 to 1, with 0 indicating that all actual negatives were correctly predicted as negative (no false positives).
A tibble with columns .metric, .estimator,
and .estimate and 1 row of values.
For grouped data frames, the number of rows returned will be the same as the number of groups.
For fall_out_vec(), a single numeric value (or NA).
There is no common convention on which factor level should
automatically be considered the "event" or "positive" result
when computing binary classification metrics. In yardstick, the default
is to use the first level. To alter this, change the argument
event_level to "second" to consider the last level of the factor the
level of interest. For multiclass extensions involving one-vs-all
comparisons (such as macro averaging), this option is ignored and
the "one" level is always the relevant result.
Macro, micro, and macro-weighted averaging is available for this metric.
The default is to select macro averaging if a truth factor with more
than 2 levels is provided. Otherwise, a standard binary calculation is done.
See vignette("multiclass", "yardstick") for more information.
All class metrics
Other class metrics:
accuracy(),
bal_accuracy(),
detection_prevalence(),
f_meas(),
j_index(),
kap(),
markedness(),
mcc(),
miss_rate(),
npv(),
ppv(),
precision(),
recall(),
roc_dist(),
sedi(),
sens(),
spec()
Other sensitivity metrics:
miss_rate(),
npv(),
ppv(),
sens(),
spec()
# Two class
data("two_class_example")
fall_out(two_class_example, truth, predicted)
# Multiclass
library(dplyr)
data(hpc_cv)
hpc_cv |>
filter(Resample == "Fold01") |>
fall_out(obs, pred)
# Groups are respected
hpc_cv |>
group_by(Resample) |>
fall_out(obs, pred)
# Weighted macro averaging
hpc_cv |>
group_by(Resample) |>
fall_out(obs, pred, estimator = "macro_weighted")
# Vector version
fall_out_vec(
two_class_example$truth,
two_class_example$predicted
)
# Making Class2 the "relevant" level
fall_out_vec(
two_class_example$truth,
two_class_example$predicted,
event_level = "second"
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.