View source: R/class-markedness.R
| markedness | R Documentation |
Markedness is defined as:
precision() + "inverse precision" - 1
where "inverse precision" is the proportion of true negatives among all predicted negatives. A related metric is Informedness, see the Details section for the relationship.
markedness(data, ...)
## S3 method for class 'data.frame'
markedness(
data,
truth,
estimate,
estimator = NULL,
na_rm = TRUE,
case_weights = NULL,
event_level = yardstick_event_level(),
...
)
markedness_vec(
truth,
estimate,
estimator = NULL,
na_rm = TRUE,
case_weights = NULL,
event_level = yardstick_event_level(),
...
)
data |
Either a |
... |
Not currently used. |
truth |
The column identifier for the true class results
(that is a |
estimate |
The column identifier for the predicted class
results (that is also |
estimator |
One of: |
na_rm |
A |
case_weights |
The optional column identifier for case weights.
This should be an unquoted column name that evaluates to a numeric column
in |
event_level |
A single string. Either |
Suppose a 2x2 table with notation:
| Reference | ||
| Predicted | Positive | Negative |
| Positive | A | B |
| Negative | C | D |
The formulas used here are:
\text{Precision} = \frac{A}{A + B}
\text{Inverse Precision} = \frac{D}{C + D}
\text{Markedness} = \text{Precision} + \text{Inverse Precision} - 1
Markedness is a metric that should be maximized. The output ranges from -1 to 1, with 1 indicating perfect predictions.
Markedness is to the predicted condition (precision and inverse precision)
what Informedness (j_index()) is to the actual condition (sensitivity and
specificity).
A tibble with columns .metric, .estimator,
and .estimate and 1 row of values.
For grouped data frames, the number of rows returned will be the same as the number of groups.
For markedness_vec(), a single numeric value (or NA).
There is no common convention on which factor level should
automatically be considered the "event" or "positive" result
when computing binary classification metrics. In yardstick, the default
is to use the first level. To alter this, change the argument
event_level to "second" to consider the last level of the factor the
level of interest. For multiclass extensions involving one-vs-all
comparisons (such as macro averaging), this option is ignored and
the "one" level is always the relevant result.
Macro, micro, and macro-weighted averaging is available for this metric.
The default is to select macro averaging if a truth factor with more
than 2 levels is provided. Otherwise, a standard binary calculation is done.
See vignette("multiclass", "yardstick") for more information.
Powers, David M W (2011). "Evaluation: From Precision, Recall and F-Score to ROC, Informedness, Markedness and Correlation". Journal of Machine Learning Technologies. 2 (1): 37-63.
All class metrics
Other class metrics:
accuracy(),
bal_accuracy(),
detection_prevalence(),
f_meas(),
fall_out(),
j_index(),
kap(),
mcc(),
miss_rate(),
npv(),
ppv(),
precision(),
recall(),
roc_dist(),
sedi(),
sens(),
spec()
# Two class
data("two_class_example")
markedness(two_class_example, truth, predicted)
# Multiclass
library(dplyr)
data(hpc_cv)
hpc_cv |>
filter(Resample == "Fold01") |>
markedness(obs, pred)
# Groups are respected
hpc_cv |>
group_by(Resample) |>
markedness(obs, pred)
# Weighted macro averaging
hpc_cv |>
group_by(Resample) |>
markedness(obs, pred, estimator = "macro_weighted")
# Vector version
markedness_vec(
two_class_example$truth,
two_class_example$predicted
)
# Making Class2 the "relevant" level
markedness_vec(
two_class_example$truth,
two_class_example$predicted,
event_level = "second"
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.