| rpiq | R Documentation |
These functions are appropriate for cases where the model outcome is a
numeric. The ratio of performance to deviation
(rpd()) and the ratio of performance to inter-quartile (rpiq())
are both measures of consistency/correlation between observed
and predicted values (and not of accuracy).
rpiq(data, ...)
## S3 method for class 'data.frame'
rpiq(data, truth, estimate, na_rm = TRUE, case_weights = NULL, ...)
rpiq_vec(truth, estimate, na_rm = TRUE, case_weights = NULL, ...)
data |
A |
... |
Not currently used. |
truth |
The column identifier for the true results
(that is |
estimate |
The column identifier for the predicted
results (that is also |
na_rm |
A |
case_weights |
The optional column identifier for case weights. This
should be an unquoted column name that evaluates to a numeric column in
|
RPIQ is a metric that should be maximized. The output ranges from 0 to Inf, with higher values indicating better model performance.
The formula for RPIQ is:
\text{RPIQ} = \frac{\text{IQR}(\text{truth})}{\text{RMSE}}
A tibble with columns .metric, .estimator,
and .estimate and 1 row of values.
For grouped data frames, the number of rows returned will be the same as the number of groups.
For rpd_vec(), a single numeric value (or NA).
Pierre Roudier
Williams, P.C. (1987) Variables affecting near-infrared reflectance spectroscopic analysis. In: Near Infrared Technology in the Agriculture and Food Industries. 1st Ed. P.Williams and K.Norris, Eds. Am. Cereal Assoc. Cereal Chem., St. Paul, MN.
Bellon-Maurel, V., Fernandez-Ahumada, E., Palagos, B., Roger, J.M. and McBratney, A., (2010). Critical review of chemometric indicators commonly used for assessing the quality of the prediction of soil attributes by NIR spectroscopy. TrAC Trends in Analytical Chemistry, 29(9), pp.1073-1081.
All numeric metrics
The closely related deviation metric: rpd()
Other numeric metrics:
ccc(),
gini_coef(),
huber_loss(),
huber_loss_pseudo(),
iic(),
mae(),
mape(),
mase(),
mpe(),
msd(),
mse(),
poisson_log_loss(),
rmse(),
rmse_relative(),
rpd(),
rsq(),
rsq_trad(),
smape()
Other consistency metrics:
ccc(),
rpd(),
rsq(),
rsq_trad()
# Supply truth and predictions as bare column names
rpd(solubility_test, solubility, prediction)
library(dplyr)
set.seed(1234)
size <- 100
times <- 10
# create 10 resamples
solubility_resampled <- bind_rows(
replicate(
n = times,
expr = sample_n(solubility_test, size, replace = TRUE),
simplify = FALSE
),
.id = "resample"
)
# Compute the metric by group
metric_results <- solubility_resampled |>
group_by(resample) |>
rpd(solubility, prediction)
metric_results
# Resampled mean estimate
metric_results |>
summarise(avg_estimate = mean(.estimate))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.